==> react-universal-canvas-0.2.2.tgz: package/lib/index.js <==
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("react"));
	else if(typeof define === 'function' && define.amd)
		define(["react"], factory);
	else if(typeof exports === 'object')
		exports["index"] = factory(require("react"));
	else
		root["index"] = factory(root["React"]);
})(this, function(__WEBPACK_EXTERNAL_MODULE_1__) {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};

/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {

/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;

/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};

/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);

/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;

/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}


/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;

/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;

/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";

/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

	var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

	var _react = __webpack_require__(1);

	var _react2 = _interopRequireDefault(_react);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

	function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

	function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

	var UniversalCanvas = function (_React$Component) {
	  _inherits(UniversalCanvas, _React$Component);

	  function UniversalCanvas(props) {
	    _classCallCheck(this, UniversalCanvas);

	    var _this = _possibleConstructorReturn(this, (UniversalCanvas.__proto__ || Object.getPrototypeOf(UniversalCanvas)).call(this, props));

	    _this.state = {
	      ratio: 1
	    };
	    _this.onTouchStart = _this.onTouchStart.bind(_this);
	    _this.onTouchMove = _this.onTouchMove.bind(_this);
	    _this.onTouchEnd = _this.onTouchEnd.bind(_this);
	    _this.setup = _this.setup.bind(_this);
	    return _this;
	  }

	  _createClass(UniversalCanvas, [{
	    key: 'update',
	    value: function update() {}
	  }, {
	    key: 'getContext',
	    value: function getContext() {
	      return this._canvas ? this._canvas.getContext('2d') : undefined;
	    }
	  }, {
	    key: 'onTouchStart',
	    value: function onTouchStart(evt) {
	      var onTouchStart = this.props.onTouchStart;

	      var _ref = evt.touches ? evt.touches[0] : evt,
	          clientX = _ref.clientX,
	          clientY = _ref.clientY;

	      this._mousedown = true;
	      if (!this._canvas) return;
	      if (evt.preventDefault) evt.preventDefault();
	      if (onTouchStart) onTouchStart({
	        clientX: clientX - this._canvas.offsetLeft,
	        clientY: clientY - this._canvas.offsetTop
	      });
	    }
	  }, {
	    key: 'onTouchMove',
	    value: function onTouchMove(evt) {
	      var _props = this.props,
	          onHoverMove = _props.onHoverMove,
	          onTouchMove = _props.onTouchMove;

	      var _ref2 = evt.touches ? evt.touches[0] : evt,
	          clientX = _ref2.clientX,
	          clientY = _ref2.clientY;

	      if (!this._canvas) return;
	      if (evt.preventDefault) evt.preventDefault();
	      if (this._mousedown) {
	        if (onTouchMove) onTouchMove({
	          clientX: clientX - this._canvas.offsetLeft,
	          clientY: clientY - this._canvas.offsetTop
	        });
	      } else {
	        if (onHoverMove) onHoverMove({
	          clientX: clientX - this._canvas.offsetLeft,
	          clientY: clientY - this._canvas.offsetTop
	        });
	      }
	    }
	  }, {
	    key: 'onTouchEnd',
	    value: function onTouchEnd(evt) {
	      var onTouchEnd = this.props.onTouchEnd;

	      this._mousedown = false;
	      if (evt.preventDefault) evt.preventDefault();
	      if (onTouchEnd) onTouchEnd({});
	    }
	  }, {
	    key: 'trigger',
	    value: function trigger(evt) {
	      switch (evt.type) {
	        case 'touchstart':
	        case 'mousedown':
	          this.onTouchStart(evt);
	          break;
	        case 'hovermove':
	        case 'touchmove':
	        case 'mousemove':
	          this.onTouchMove(evt);
	          break;
	        case 'touchend':
	        case 'mouseup':
	          this.onTouchEnd(evt);
	          break;
	      }
	    }
	  }, {
	    key: 'setup',
	    value: function setup(canvas) {
	      var _props2 = this.props,
	          style = _props2.style,
	          width = _props2.width,
	          height = _props2.height;

	      this._canvas = canvas;
	      var context = this.getContext();
	      if (!context) return;
	      var devicePixelRatio = window.devicePixelRatio || 1;
	      var backingStoreRatio = context.webkitBackingStorePixelRatio || context.mozBackingStorePixelRatio || context.msBackingStorePixelRatio || context.oBackingStorePixelRatio || context.backingStorePixelRatio || 1;
	      var ratio = devicePixelRatio / backingStoreRatio;
	      this.setState({
	        ratio: ratio,
	        fWidth: (width || style.width) * ratio,
	        fHeight: (height || style.height) * ratio
	      });
	    }
	  }, {
	    key: 'componentWillReceiveProps',
	    value: function componentWillReceiveProps(nextProps) {
	      var _props3 = this.props,
	          style = _props3.style,
	          width = _props3.width,
	          height = _props3.height;

	      var currentWidth = width || style.width;
	      var currentHeight = height || style.height;
	      var nextStyle = nextProps.style || {};
	      var nextWidth = nextProps.width || nextStyle.width;
	      var nextHeight = nextProps.height || nextStyle.height;
	      if (currentWidth !== nextWidth || currentHeight !== nextHeight) {
	        this.setup(this._canvas);
	      }
	    }
	  }, {
	    key: 'render',
	    value: function render() {
	      var _props4 = this.props,
	          style = _props4.style,
	          width = _props4.width,
	          height = _props4.height;
	      var _state = this.state,
	          fWidth = _state.fWidth,
	          fHeight = _state.fHeight;

	      return _react2.default.createElement('canvas', {
	        style: _extends({}, style, {
	          width: (width || style.width) + 'px',
	          height: (height || style.height) + 'px'
	        }),
	        ref: this.setup,
	        onTouchStart: this.onTouchStart,
	        onTouchMove: this.onTouchMove,
	        onTouchEnd: this.onTouchEnd,
	        onMouseDown: this.onTouchStart,
	        onMouseMove: this.onTouchMove,
	        onMouseUp: this.onTouchEnd,
	        width: fWidth || width || style.width,
	        height: fHeight || height || style.height
	      });
	    }
	  }, {
	    key: 'width',
	    get: function get() {
	      return this._canvas ? this._canvas.width : 0;
	    }
	  }, {
	    key: 'height',
	    get: function get() {
	      return this._canvas ? this._canvas.height : 0;
	    }
	  }, {
	    key: 'ratio',
	    get: function get() {
	      return this.state.ratio;
	    }
	  }]);

	  return UniversalCanvas;
	}(_react2.default.Component);

	UniversalCanvas.defaultProps = {};

	module.exports = UniversalCanvas;

/***/ },
/* 1 */
/***/ function(module, exports) {

	module.exports = __WEBPACK_EXTERNAL_MODULE_1__;

/***/ }
/******/ ])
});
;

==> react-universal-canvas-0.2.4.tgz: package/lib/index.js <==
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("react"));
	else if(typeof define === 'function' && define.amd)
		define(["react"], factory);
	else if(typeof exports === 'object')
		exports["index"] = factory(require("react"));
	else
		root["index"] = factory(root["React"]);
})(this, function(__WEBPACK_EXTERNAL_MODULE_1__) {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};

/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {

/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;

/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};

/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);

/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;

/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}


/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;

/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;

/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";

/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

	var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

	var _react = __webpack_require__(1);

	var _react2 = _interopRequireDefault(_react);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

	function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

	function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

	var UniversalCanvas = function (_React$Component) {
	  _inherits(UniversalCanvas, _React$Component);

	  function UniversalCanvas(props) {
	    _classCallCheck(this, UniversalCanvas);

	    var _this = _possibleConstructorReturn(this, (UniversalCanvas.__proto__ || Object.getPrototypeOf(UniversalCanvas)).call(this, props));

	    _this.state = {
	      ratio: 1
	    };
	    _this.onTouchStart = _this.onTouchStart.bind(_this);
	    _this.onTouchMove = _this.onTouchMove.bind(_this);
	    _this.onTouchEnd = _this.onTouchEnd.bind(_this);
	    _this.setup = _this.setup.bind(_this);
	    return _this;
	  }

	  _createClass(UniversalCanvas, [{
	    key: 'update',
	    value: function update() {}
	  }, {
	    key: 'getContext',
	    value: function getContext() {
	      return this._canvas ? this._canvas.getContext('2d') : undefined;
	    }
	  }, {
	    key: 'onTouchStart',
	    value: function onTouchStart(evt) {
	      var onTouchStart = this.props.onTouchStart;

	      var _ref = evt.touches ? evt.touches[0] : evt,
	          clientX = _ref.clientX,
	          clientY = _ref.clientY;

	      this._mousedown = true;
	      if (!this._canvas) return;
	      if (evt.preventDefault) evt.preventDefault();
	      if (onTouchStart) onTouchStart({
	        clientX: clientX - this._canvas.offsetLeft,
	        clientY: clientY - this._canvas.offsetTop
	      });
	    }
	  }, {
	    key: 'onTouchMove',
	    value: function onTouchMove(evt) {
	      var _props = this.props,
	          onHoverMove = _props.onHoverMove,
	          onTouchMove = _props.onTouchMove;

	      var _ref2 = evt.touches ? evt.touches[0] : evt,
	          clientX = _ref2.clientX,
	          clientY = _ref2.clientY;

	      if (!this._canvas) return;
	      if (evt.preventDefault) evt.preventDefault();
	      if (this._mousedown) {
	        if (onTouchMove) onTouchMove({
	          clientX: clientX - this._canvas.offsetLeft,
	          clientY: clientY - this._canvas.offsetTop
	        });
	      } else {
	        if (onHoverMove) onHoverMove({
	          clientX: clientX - this._canvas.offsetLeft,
	          clientY: clientY - this._canvas.offsetTop
	        });
	      }
	    }
	  }, {
	    key: 'onTouchEnd',
	    value: function onTouchEnd(evt) {
	      var onTouchEnd = this.props.onTouchEnd;

	      this._mousedown = false;
	      if (evt.preventDefault) evt.preventDefault();
	      if (onTouchEnd) onTouchEnd({});
	    }
	  }, {
	    key: 'trigger',
	    value: function trigger(evt) {
	      switch (evt.type) {
	        case 'touchstart':
	        case 'mousedown':
	          this.onTouchStart(evt);
	          break;
	        case 'hovermove':
	        case 'touchmove':
	        case 'mousemove':
	          this.onTouchMove(evt);
	          break;
	        case 'touchend':
	        case 'mouseup':
	          this.onTouchEnd(evt);
	          break;
	      }
	    }
	  }, {
	    key: 'setup',
	    value: function setup(canvas) {
	      var _props2 = this.props,
	          width = _props2.width,
	          height = _props2.height;

	      this._canvas = canvas;
	      var context = this.getContext();
	      if (!context) return;
	      var devicePixelRatio = window.devicePixelRatio || 1;
	      var backingStoreRatio = context.webkitBackingStorePixelRatio || context.mozBackingStorePixelRatio || context.msBackingStorePixelRatio || context.oBackingStorePixelRatio || context.backingStorePixelRatio || 1;
	      var ratio = devicePixelRatio / backingStoreRatio;
	      this.setState({
	        ratio: ratio,
	        fWidth: width * ratio,
	        fHeight: height * ratio,
	        sWidth: width,
	        sHeight: height
	      });
	    }
	  }, {
	    key: 'componentWillReceiveProps',
	    value: function componentWillReceiveProps(nextProps) {
	      var _props3 = this.props,
	          width = _props3.width,
	          height = _props3.height;

	      var currentWidth = width;
	      var currentHeight = height;
	      var nextWidth = nextProps.width;
	      var nextHeight = nextProps.height;
	      if (currentWidth !== nextWidth || currentHeight !== nextHeight) {
	        this.setup(this._canvas);
	      }
	    }
	  }, {
	    key: 'render',
	    value: function render() {
	      var _this2 = this;

	      var _props4 = this.props,
	          style = _props4.style,
	          width = _props4.width,
	          height = _props4.height;
	      var _state = this.state,
	          sWidth = _state.sWidth,
	          sHeight = _state.sHeight,
	          fWidth = _state.fWidth,
	          fHeight = _state.fHeight;

	      return _react2.default.createElement('canvas', {
	        style: _extends({}, style, {
	          width: sWidth + 'px',
	          height: sHeight + 'px'
	        }),
	        ref: function ref(c) {
	          if (c) setTimeout(function () {
	            _this2.setup(c);
	          }, 0);
	        },
	        onTouchStart: this.onTouchStart,
	        onTouchMove: this.onTouchMove,
	        onTouchEnd: this.onTouchEnd,
	        onMouseDown: this.onTouchStart,
	        onMouseMove: this.onTouchMove,
	        onMouseUp: this.onTouchEnd,
	        width: fWidth || width,
	        height: fHeight || height
	      });
	    }
	  }, {
	    key: 'width',
	    get: function get() {
	      return this._canvas ? this._canvas.width : 0;
	    }
	  }, {
	    key: 'height',
	    get: function get() {
	      return this._canvas ? this._canvas.height : 0;
	    }
	  }, {
	    key: 'ratio',
	    get: function get() {
	      return this.state.ratio;
	    }
	  }]);

	  return UniversalCanvas;
	}(_react2.default.Component);

	UniversalCanvas.defaultProps = {};

	module.exports = UniversalCanvas;

/***/ },
/* 1 */
/***/ function(module, exports) {

	module.exports = __WEBPACK_EXTERNAL_MODULE_1__;

/***/ }
/******/ ])
});
;
